Searching.

- [X] fix README links on pypi
- [X] autoversioning
- [X] `--version`
- [X] implement changelog
- [X] args that match dir search the dir
- [X] args that match files add them to the list
- [X] args that match neither are substring matches applied to tasks
